summaryrefslogtreecommitdiff
path: root/ace/ACE.h
diff options
context:
space:
mode:
authorirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-07-17 01:50:34 +0000
committerirfan <irfan@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-07-17 01:50:34 +0000
commitee2fe403967b9f538f77adae0208eb80a0101360 (patch)
tree73f902d5c7e4c2546d269ce453265dacd856f91f /ace/ACE.h
parenta4d31a757f3bf33edc29691e05e46d519bad7f22 (diff)
downloadATCD-ee2fe403967b9f538f77adae0208eb80a0101360.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/ACE.h')
-rw-r--r--ace/ACE.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/ace/ACE.h b/ace/ACE.h
index 59d5373d78b..88b74211d55 100644
--- a/ace/ACE.h
+++ b/ace/ACE.h
@@ -72,8 +72,9 @@ public:
static u_int compiler_beta_version (void);
// E.g., the "0" in SunPro C++ 4.32.0
- static int out_of_file_descriptors (int error);
- // Check if error indicates the process being out of file descriptors.
+ static int out_of_handles (int error);
+ // Check if error indicates the process being out of handles (file
+ // descriptors).
// = Recv operations that factor out differences between Win32 and UNIX.
static ssize_t recv (ACE_HANDLE handle,